import React, { useState, useEffect } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';
import { createEmployee } from "../../services_1/employeeService";

const CLASSES = {
  container: 'flex flex-row',
  mainContent: 'w-full flex flex-col min-h-screen text-black',
  innerContent: 'min-h-screen text-gray-800 p-6',
  header: 'flex justify-between items-center',
  headerTitle: 'flex items-center',
  backButton: 'text-[#0e355b] text-xl',
  title: 'text-2xl font-semibold text-[#0e355b]',
  formGrid: 'grid grid-cols-1 md:grid-cols-3 gap-6',
  imageSection: 'space-y-6',
  imageWrapper: 'text-center',
  imageContainer: 'inline-block relative',
  imagePreview: 'bg-gray-300 w-24 h-24 rounded-full mx-auto overflow-hidden',
  noImage: 'w-full h-full flex items-center justify-center text-gray-500',
  hiddenInput: 'hidden',
  uploadButton: 'absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-gray-700 text-white text-xs px-2 py-1 rounded-full',
  formSection: 'md:col-span-2 space-y-4',
  formGroup: 'text-gray-800 font-medium',
  formInput: 'p-2 border-b border-gray-400 focus:border-gray-700',
  formSelect: 'p-2 border-b border-gray-400 focus:border-gray-700',
  submitButton: 'bg-[#0e355b] text-white py-2 px-4 rounded-md',
};

const AddEmployee = () => {
  const navigate = useNavigate();
  const [employeeData, setEmployeeData] = useState({
    firstname: '',
    lastname: '',
    age: '',
    gender: '',
    email: '',
    mobile: '',
    address: {
      address_line_1: '',
      address_line_2: '',
      nearby_landmark: '',
      pincode: '',
      city_id: '',
    },
    image: null,
  });
  const [cities, setCities] = useState([]);
  const [imagePreview, setImagePreview] = useState(null);

  useEffect(() => {
    const fetchCities = async () => {
      try {
        const response = await axiosInstance.get('/cities');
        if (Array.isArray(response.data)) {
          setCities(response.data);
        } else {
          console.error('Error: Data is not an array', response.data);
        }
      } catch (error) {
        console.error('Error fetching cities:', error.response ? error.response.data : error.message);
      }
    };

    fetchCities();
  }, []);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setEmployeeData((prevData) => ({
      ...prevData,
      [name]: value,
    }));
  };

  const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      setEmployeeData({
        ...employeeData,
        image: file,
      });
      setImagePreview(URL.createObjectURL(file));
    }
  };

  const handleAddEmployeeSubmit = async (e) => {
    e.preventDefault();
    const formData = new FormData();
    Object.keys(employeeData).forEach((key) => {
      formData.append(key, employeeData[key]);
    });

    try {
      const data = await createEmployee(employeeData);
      console.log('Employee added successfully:', data);
      navigate('/employees');
    } catch (error) {
      console.error('Error adding employee:', error.response || error.message);
    }
  };

  return (
    <div className={CLASSES.container}>
      <Sidebar />
      <div className={CLASSES.mainContent}>
        <div className={CLASSES.innerContent}>
          <div className={CLASSES.header}>
            <div className={CLASSES.headerTitle}>
              <Link to="/employees" className={CLASSES.backButton}>
                <FontAwesomeIcon icon={faChevronLeft} />
              </Link>
              <h1 className={CLASSES.title}>create employee account</h1>
            </div>
          </div>
          <div className={CLASSES.formGrid}>
            <div className={CLASSES.imageSection}>
              <div className={CLASSES.imageWrapper}>
                <div className={CLASSES.imageContainer}>
                  <div className={CLASSES.imagePreview}>
                    {imagePreview ? (
                      <img
                        src={imagePreview}
                        alt="Employee"
                        className="w-full h-full object-cover"
                      />
                    ) : (
                      <div className={CLASSES.noImage}>no image</div>
                    )}
                  </div>
                  <input
                    type="file"
                    accept="image/*"
                    className={CLASSES.hiddenInput}
                    id="imageUpload"
                    onChange={handleImageChange}
                  />
                  <button
                    type="button"
                    onClick={() => document.getElementById('imageUpload').click()}
                    className={CLASSES.uploadButton}
                  >
                    
                  </button>
                </div>
              </div>
            </div>
            <div className={CLASSES.formSection}>
              <form onSubmit={handleAddEmployeeSubmit}>
                <div>
                  <label className={CLASSES.formGroup}>first name:</label>
                  <input
                    type="text"
                    name="firstname"
                    value={employeeData.firstname}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>last name:</label>
                  <input
                    type="text"
                    name="lastname"
                    value={employeeData.lastname}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
                <div>
                  <label className={CLASSES.formGroup}>age:</label>
                  <input
                    type="number"
                    name="age"
                    value={employeeData.age}
                    onChange={handleInputChange}
                    className={CLASSES.formInput}
                  />
                </div>
               
                <div className={CLASSES.formGroup}>
                  <label htmlFor="email">Email</label>
                  <input
                    type="email"
                    id="email"
                    name="email"
                    className={CLASSES.formInput}
                    value={employeeData.email}
                    onChange={handleInputChange}
                  />
                </div>
                <div className={CLASSES.formGroup}>
                  <label htmlFor="mobile">Mobile Number</label>
                  <input
                    type="text"
                    id="mobile"
                    name="mobile"
                    className={CLASSES.formInput}
                    value={employeeData.mobile}
                    onChange={handleInputChange}
                  />
                </div>
                <div className={CLASSES.formGroup}>
                  <label htmlFor="address_line_1">Address Line 1</label>
                  <input
                    type="text"
                    id="address_line_1"
                    name="address.address_line_1"
                    className={CLASSES.formInput}
                    value={employeeData.address.address_line_1}
                    onChange={handleInputChange}
                  />
                </div>
                <div className={CLASSES.formGroup}>
                  <label htmlFor="address_line_2">Address Line 2</label>
                  <input
                    type="text"
                    id="address_line_2"
                    name="address.address_line_2"
                    className={CLASSES.formInput}
                    value={employeeData.address.address_line_2}
                    onChange={handleInputChange}
                  />
                </div>
                <div className={CLASSES.formGroup}>
                  <label htmlFor="nearby_landmark">Nearby Landmark</label>
                  <input
                    type="text"
                    id="nearby_landmark"
                    name="address.nearby_landmark"
                    className={CLASSES.formInput}
                    value={employeeData.address.nearby_landmark}
                    onChange={handleInputChange}
                  />
                </div>
                <div className={CLASSES.formGroup}>
                  <label htmlFor="pincode">Pincode</label>
                  <input
                    type="text"
                    id="pincode"
                    name="address.pincode"
                    className={CLASSES.formInput}
                    value={employeeData.address.pincode}
                    onChange={handleInputChange}
                  />
                </div>
                <div className={CLASSES.formGroup}>
                  <label htmlFor="city_id">City</label>
                  <select
                    id="city_id"
                    name="address.city_id"
                    className={CLASSES.formSelect}
                    value={employeeData.address.city_id}
                    onChange={handleInputChange}
                  >
                    <option value="">Select City</option>
                    {cities.map((city) => (
                      <option key={city.id} value={city.id}>
                        {city.name}
                      </option>
                    ))}
                  </select>
                </div>
                
                <button type="submit" className={CLASSES.submitButton}>
                  add employee
                </button>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddEmployee;
